[PATCH 28/37] mi: miComputeClips based on paintable not viewable
Adam Jackson
ajax at redhat.com
Wed Oct 8 08:04:52 PDT 2014
Signed-off-by: Adam Jackson <ajax at redhat.com>
---
mi/mivaltree.c | 13 ++++++-------
1 file changed, 6 insertions(+), 7 deletions(-)
diff --git a/mi/mivaltree.c b/mi/mivaltree.c
index 94f88fe..b963740 100644
--- a/mi/mivaltree.c
+++ b/mi/mivaltree.c
@@ -181,7 +181,7 @@ miShapedWindowIn(RegionPtr universe, RegionPtr bounding,
*-----------------------------------------------------------------------
* miComputeClips --
* Recompute the clipList, borderClip, exposed and borderExposed
* regions for pParent and its children. Only viewable windows are
* taken into account.
*
* Results:
@@ -295,14 +295,13 @@ miComputeClips(WindowPtr pParent,
(oldVis == VisibilityUnobscured))) {
pChild = pParent;
while (1) {
- if (pChild->viewable) {
+ if (pChild->paintable) {
if (pChild->visibility != VisibilityFullyObscured) {
RegionTranslate(&pChild->borderClip, dx, dy);
RegionTranslate(&pChild->clipList, dx, dy);
pChild->drawable.serialNumber = NEXT_SERIAL_NUMBER;
if (pScreen->ClipNotify)
(*pScreen->ClipNotify) (pChild, dx, dy);
-
}
if (pChild->valdata) {
RegionNull(&pChild->valdata->after.borderExposed);
@@ -401,22 +400,22 @@ miComputeClips(WindowPtr pParent,
((pChild->drawable.y == pParent->lastChild->drawable.y) &&
(pChild->drawable.x < pParent->lastChild->drawable.x))) {
for (; pChild; pChild = pChild->nextSib) {
- if (pChild->viewable && !TreatAsTransparent(pChild))
+ if (pChild->paintable && !TreatAsTransparent(pChild))
RegionAppend(&childUnion, &pChild->borderSize);
}
}
else {
for (pChild = pParent->lastChild; pChild; pChild = pChild->prevSib) {
- if (pChild->viewable && !TreatAsTransparent(pChild))
+ if (pChild->paintable && !TreatAsTransparent(pChild))
RegionAppend(&childUnion, &pChild->borderSize);
}
}
RegionValidate(&childUnion, &overlap);
for (pChild = pParent->firstChild; pChild; pChild = pChild->nextSib) {
- if (pChild->viewable) {
+ if (pChild->paintable) {
/*
* If the child is viewable, we want to remove its extents
* from the current universe, but we only re-clip it if
* it's been marked.
*/
@@ -181,7 +181,7 @@ miShapedWindowIn(RegionPtr universe, RegionPtr bounding,
* miComputeClips --
* Recompute the clipList, borderClip, exposed and borderExposed
- * regions for pParent and its children. Only viewable windows are
+ * regions for pParent and its children. Only paintable windows are
* taken into account.
*
@@ -401,22 +400,22 @@ miComputeClips(WindowPtr pParent,
/*
- * If the child is viewable, we want to remove its extents
+ * If the child is paintable, we want to remove its extents
* from the current universe, but we only re-clip it if
* it's been marked.
--
1.9.3
More information about the xorg-devel
mailing list